aom_codec_version

Function aom_codec_version 

pub unsafe extern "C" fn aom_codec_version() -> c_int
Return the version information (as an integer)

Returns a packed encoding of the library version number. This will only include the major.minor.patch component of the version number. Note that this encoded value should be accessed through the macros provided, as the encoding may change in the future.