pub unsafe extern "C" fn aom_codec_version_str() -> *const c_charExpand description
Return the version information (as a string)
Returns a printable string containing the full library version number. This may contain additional text following the three digit version number, as to indicate release candidates, pre-release versions, etc.